@@ -1,5 +1,11 @@
-import six
-from graphql.language.ast import BooleanValue, FloatValue, IntValue, StringValue
+from typing import Any
+
+from graphql.language.ast import (
+    BooleanValueNode,
+    FloatValueNode,
+    IntValueNode,
+    StringValueNode,
+)
 
 from .base import BaseOptions, BaseType
 from .unmountedtype import UnmountedType
@@ -69,13 +75,40 @@ class Int(Scalar):
     parse_value = coerce_int
 
     @staticmethod
-    def parse_literal(ast):
-        if isinstance(ast, IntValue):
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, IntValueNode):
             num = int(ast.value)
             if MIN_INT <= num <= MAX_INT:
                 return num
 
 
+class BigInt(Scalar):
+    """
+    The `BigInt` scalar type represents non-fractional whole numeric values.
+    `BigInt` is not constrained to 32-bit like the `Int` type and thus is a less
+    compatible type.
+    """
+
+    @staticmethod
+    def coerce_int(value):
+        try:
+            num = int(value)
+        except ValueError:
+            try:
+                num = int(float(value))
+            except ValueError:
+                return None
+        return num
+
+    serialize = coerce_int
+    parse_value = coerce_int
+
+    @staticmethod
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, IntValueNode):
+            return int(ast.value)
+
+
 class Float(Scalar):
     """
     The `Float` scalar type represents signed double-precision fractional
@@ -95,8 +128,8 @@ class Float(Scalar):
     parse_value = coerce_float
 
     @staticmethod
-    def parse_literal(ast):
-        if isinstance(ast, (FloatValue, IntValue)):
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, (FloatValueNode, IntValueNode)):
             return float(ast.value)
 
 
@@ -110,15 +143,15 @@ class String(Scalar):
     @staticmethod
     def coerce_string(value):
         if isinstance(value, bool):
-            return u"true" if value else u"false"
-        return six.text_type(value)
+            return "true" if value else "false"
+        return str(value)
 
     serialize = coerce_string
     parse_value = coerce_string
 
     @staticmethod
-    def parse_literal(ast):
-        if isinstance(ast, StringValue):
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, StringValueNode):
             return ast.value
 
 
@@ -131,8 +164,8 @@ class Boolean(Scalar):
     parse_value = bool
 
     @staticmethod
-    def parse_literal(ast):
-        if isinstance(ast, BooleanValue):
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, BooleanValueNode):
             return ast.value
 
 
@@ -149,6 +182,6 @@ class ID(Scalar):
     parse_value = str
 
     @staticmethod
-    def parse_literal(ast):
-        if isinstance(ast, (StringValue, IntValue)):
+    def parse_literal(ast, _variables=None):
+        if isinstance(ast, (StringValueNode, IntValueNode)):
             return ast.value
